/* 
 * File:   Mp3_13.c
 *
 * Created on 2018/11/06, 20:23
 */

#include <18F26K22.h>

#device ansi
#device const=read_only
#device PASS_STRINGS=IN_RAM
#opt compress

#fuses INTRC_IO,NOPLLEN,NOFCMEN,NOIESO,NOBROWNOUT,NOWDT,NOPBADEN,NOMCLR,STVREN,NOLVP,NOXINST,NOCPB,NOCPD,NODEBUG,CCP3B5
#use delay (clock=8000000)

#include <stdio.h>
#include <stdlib.h>

typedef unsigned int8   uint8_t;
typedef unsigned int16  uint16_t;
typedef unsigned int32  uint32_t;

// 電源
#define PIN_PLOCK           PIN_C6      //  (output)
#define PIN_PDOWN           PIN_B4      // detect power off (input)
//#define PIN_DIRECT_PDOWN    PIN_C1      // (output)
//#define PIN_DETECT_PDOWN    PIN_C0      // (input)

// LCD
#define PIN_LCD_DI          PIN_C5
#define PIN_LCD_RW          PIN_A0
#define PIN_LCD_E           PIN_A1
#define PIN_LCD_D0          PIN_A2
#define PIN_LCD_D1          PIN_A3
#define PIN_LCD_D2          PIN_A4
#define PIN_LCD_D3          PIN_A5
#define PIN_LCD_D4          PIN_C4
#define PIN_LCD_D5          PIN_A7
#define PIN_LCD_D6          PIN_A6
#define PIN_LCD_D7          PIN_C0
#define PIN_LCD_CS1         PIN_C1
#define PIN_LCD_CS2         PIN_C2
#define PIN_LCD_RESET       PIN_C3
#define PIN_LCD_BKLT        PIN_C7      // バックライト制御

/* 各制御線を操作するためのマクロ */
#define GLCD_RS_H		output_high(PIN_LCD_DI)         // PORT_LCD_CTRL|=(1<<PIN_LCD_RS)
#define GLCD_RS_L		output_low(PIN_LCD_DI)          // PORT_LCD_CTRL&=~(1<<PIN_LCD_RS)
#define GLCD_RW_H		output_high(PIN_LCD_RW)         // PORT_LCD_CTRL|=(1<<PIN_LCD_RW)
#define GLCD_RW_L		output_low(PIN_LCD_RW)          // PORT_LCD_CTRL&=~(1<<PIN_LCD_RW)
#define GLCD_E_H		output_high(PIN_LCD_E)          // PORT_LCD_CTRL|=(1<<PIN_LCD_E)
#define GLCD_E_L		output_low(PIN_LCD_E)           // PORT_LCD_CTRL&=~(1<<PIN_LCD_E)
#define GLCD_CS1_H		output_high(PIN_LCD_CS1)        // PORT_LCD_CTRL|=(1<<PIN_LCD_CS1)
#define GLCD_CS1_L		output_low(PIN_LCD_CS1)         // PORT_LCD_CTRL&=~(1<<PIN_LCD_CS1)
#define GLCD_CS2_H		output_high(PIN_LCD_CS2)        // PORT_LCD_CTRL|=(1<<PIN_LCD_CS2)
#define GLCD_CS2_L		output_low(PIN_LCD_CS2)         // PORT_LCD_CTRL&=~(1<<PIN_LCD_CS2)
#define GLCD_RST_H		output_high(PIN_LCD_RESET)      // PORT_LCD_CTRL|=(1<<PIN_LCD_RST)
#define GLCD_RST_L		output_low(PIN_LCD_RESET)       // PORT_LCD_CTRL&=~(1<<PIN_LCD_RST)
#define GLCD_BKLT_ON    output_high(PIN_LCD_BKLT)       // バックライトオン
#define GLCD_BKLT_OFF   output_low(PIN_LCD_BKLT)

/* 液晶ディスプレイ用コマンドマクロ */
#define GLCD_DISP_ON		GLCD_RS_L;glcd_write(0b00111111)
#define GLCD_DISP_OF		GLCD_RS_L;glcd_write(0b00111110)
#define GLCD_SETADRS(X)     GLCD_RS_L;glcd_write(0b01000000|((X)&0b00111111))
#define GLCD_SETPAGE(X)     GLCD_RS_L;glcd_write(0b10111000|((X)&0b00000111))
#define GLCD_STRTLNE(X)     GLCD_RS_L;glcd_write(0b11000000|((X)&0b00111111))
#define GLCD_DATA(X)		GLCD_RS_H;glcd_write((X))

#define LCD_WIDTH       128
#define LCD_PAGES       8
#define LCD_BUF_SIZE    1024

// SPI
#define SPI_MODE_0      (SPI_SCK_IDLE_LOW | SPI_XMIT_L_TO_H)
#define SPI_MODE_1      (SPI_SCK_IDLE_LOW)
#define SPI_MODE_2      (SPI_SCK_IDLE_HIGH)
#define SPI_MODE_3      (SPI_SCK_IDLE_HIGH | SPI_XMIT_L_TO_H)

// Raspberry PI からSPIを通じて送られるコマンド
#define CMD_IMAGEDATA       0xF1        // イメージデータ送信開始
#define CMD_LCDDISPON       0xF2        // LCD表示をオン(受信済みイメージデータを再表示)
#define CMD_LCDDISPOFF      0xF3        // LCD表示をオフ
#define CMD_POWERDOWN       0xF4        // 電源オフ

#define sw_pdown()      input(PIN_PDOWN)

#define TIMER0_INIT     0

static volatile BOOLEAN     EVENT_SWPDOWN;
static uint16_t             WaitMsCycle;
static uint8_t              LcdBuf[LCD_BUF_SIZE];       // １画面分のLCDデータバッファ
static volatile uint8_t     SpiTimer;

void InitApp();
void glcd_write(uint8_t cmd);
void glcd_fill(uint8_t patt);
void glcd_init(void);
void disp_lcd();
void wait_ms(uint16_t ms);

void test_led(int no);

#if 0
/* 秋月のサンプル画像データ(128x64) */
//const prog_uchar img_dat[]={
const uint8_t img_dat[1024]={
	0x00,0x00,0x30,0x30,0x38,0xF8,0xF8,0x18,0x0C,0x08,0xE0,0xE0,0x60,0xFC,0xFC,0xFC,
	0x00,0x00,0xF0,0xF0,0xF0,0x00,0x00,0x00,0x00,0xF8,0xF8,0xF8,0x18,0x18,0x18,0x18,
	0x18,0x18,0x18,0x18,0x18,0xF8,0xF8,0xF8,0x00,0x00,0x00,0x00,0xC0,0xD8,0x58,0x58,
	0x58,0x58,0x58,0x58,0xF8,0xF8,0xF8,0x58,0x58,0x58,0x58,0x58,0xD8,0xC0,0xC0,0x00,
	0x00,0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x98,0x98,0x98,0xD8,0xD8,0xF8,0xF8,
	0x78,0x38,0x10,0x00,0x00,0x00,0x20,0xF0,0xF0,0xC0,0x80,0x00,0x98,0xB8,0xF8,0xF8,
	0xD8,0xD8,0xD8,0xF8,0xF8,0xB8,0xB8,0x98,0x00,0x00,0x00,0x18,0x98,0x98,0x98,0xF8,
	0xF8,0xF8,0x98,0x9C,0x9C,0x9C,0x98,0xF8,0xF8,0xF8,0x98,0x98,0x98,0x18,0x00,0x00,
	0x00,0x00,0xC3,0xE3,0x7F,0xFF,0xFF,0x3B,0x73,0x2C,0x0F,0x0F,0xC0,0xFF,0xFF,0x7F,
	0xF8,0xDE,0x1F,0x0F,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x63,0x63,0x63,0x63,
	0x63,0x63,0x63,0x63,0x63,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x07,0xF7,0xF0,0xF5,
	0x55,0x55,0x55,0x50,0xF7,0xF7,0xF7,0x50,0x55,0x55,0x55,0xF0,0xF7,0xF7,0x07,0x00,
	0x00,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xFF,0xFF,0xFF,0x1B,0x19,0x19,0x18,
	0x18,0x18,0x18,0x18,0x00,0x00,0x0C,0x0C,0xFD,0xFD,0x00,0x00,0xFF,0xFF,0x6D,0x6D,
	0x6D,0xFF,0xFF,0x6D,0x6D,0x6D,0xFF,0xFF,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x31,
	0xD9,0xDF,0xCF,0xC7,0xC1,0xCF,0xDF,0xDF,0xD9,0x19,0x19,0xFF,0xFF,0x00,0x00,0x00,
	0x00,0x01,0x03,0x01,0x00,0x1F,0x1F,0x00,0x08,0x1C,0x0E,0x07,0x03,0x01,0x00,0x00,
	0x01,0x07,0x0F,0x1E,0x0C,0x00,0x08,0x0C,0x1F,0x0F,0x07,0x01,0x00,0x00,0x00,0x00,
	0x00,0x00,0x18,0x18,0x18,0x1F,0x1F,0x0F,0x00,0x00,0x00,0x00,0x00,0x07,0x07,0x07,
	0x02,0x02,0x02,0x02,0x0F,0x1F,0x1F,0x1A,0x1A,0x1A,0x1A,0x1B,0x1B,0x1F,0x1E,0x0E,
	0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x1F,0x1F,0x0F,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x08,0x1C,0x0E,0x07,0x03,0x06,0x0C,0x0B,0x1B,0x18,0x18,
	0x18,0x1B,0x1B,0x18,0x1B,0x1B,0x1B,0x1B,0x18,0x08,0x00,0x00,0x1F,0x1F,0x1F,0x00,
	0x0F,0x0F,0x0F,0x06,0x06,0x06,0x07,0x07,0x1F,0x18,0x18,0x1F,0x1F,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE0,0x30,0xB0,0x38,0xB8,0x7C,0xFC,0x7C,0xFC,
	0x7C,0xFC,0xFC,0xF8,0xF8,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x02,0x02,0x02,0x02,0x04,0x04,0x04,0x04,0x04,0x04,0x08,
	0x08,0x08,0x08,0x38,0x24,0x24,0x3C,0x24,0x24,0x3C,0x44,0x48,0x78,0x48,0x48,0x78,
	0x48,0x50,0x20,0x20,0x20,0x20,0x20,0x20,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xE0,0x20,0xD0,
	0x30,0xD0,0x50,0x50,0x20,0xE0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xAA,0x00,0xAA,0x00,0xAA,0x00,0xAA,
	0x00,0xAA,0x00,0xFE,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x0C,0xEC,0xEC,0xEC,0x0C,0x0C,0x0C,0x0C,0x3C,0xFC,0xFC,0x80,0x00,
	0x00,0x00,0x00,0x00,0x00,0xD8,0xBC,0x78,0x20,0xD8,0xD8,0xD8,0xFC,0xFC,0xD8,0xD8,
	0x18,0xFC,0xFC,0xFC,0xCC,0xFC,0xFC,0xFC,0x00,0x00,0x00,0xF0,0xF0,0xF0,0x30,0x30,
	0x30,0x30,0x30,0xFC,0xFC,0xFC,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,0xE0,0x01,0x3E,
	0xFE,0xC2,0x03,0x02,0x01,0xE0,0x1F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x04,0xFE,0x04,0x0A,0x08,0x0A,0xF8,0x0A,
	0x08,0x1A,0xF0,0x1B,0x04,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x80,0xC0,0xF8,0xFF,0x3F,0x07,0x00,0x00,0x00,0x00,0x00,0x07,0x1F,0xFF,0xF8,
	0xE0,0x80,0x00,0x00,0x00,0x01,0xF3,0xF3,0x62,0xBF,0xBF,0xBF,0xF2,0xF2,0xBF,0xBF,
	0x80,0xFF,0xFF,0x7F,0x18,0xFF,0xFF,0xFF,0x00,0x00,0x80,0xFF,0xFF,0x3F,0xF0,0xF0,
	0xF0,0x30,0x30,0x3F,0x3F,0x3F,0x33,0x33,0x33,0xF3,0xF3,0xF3,0x03,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x02,0xFC,
	0x07,0x07,0x04,0xFC,0x02,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x7F,0x00,0x00,0x00,0x00,0xFF,0x00,
	0x00,0x00,0x07,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
	0x0E,0x07,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
	0x07,0x0F,0x07,0x00,0x00,0x07,0x0F,0x03,0x00,0x01,0x01,0x01,0x0F,0x0F,0x01,0x01,
	0x05,0x0F,0x07,0x0C,0x0C,0x0F,0x0F,0x87,0x80,0x84,0x8F,0x0F,0x03,0x00,0x0F,0x0F,
	0x0F,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x06,0x0F,0x0F,0x0F,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,
	0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
	0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x08,0x08,0x08,0x08,0x08,0x14,0x12,
	0x1E,0x12,0x12,0x1E,0x12,0x11,0x0F,0x09,0x09,0x0F,0x09,0x09,0x0E,0x02,0x02,0x02,
	0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

// 本プログラムソースに焼き付けたイメージデータを表示
void disp_akizuki_sample(){
    
	uint8_t buf,x,y;
	uint16_t cnt=0;

	//init_io();		/* I/Oポートの初期化 */
	//glcd_init();		/* 液晶モジュールの初期化 */

	for(y=0;y<8;y++){
		GLCD_CS1_H;
		GLCD_SETPAGE(y);
		GLCD_SETADRS(0);
		GLCD_CS1_L;

		GLCD_CS2_H;
		GLCD_SETPAGE(y);
		GLCD_SETADRS(0);
		GLCD_CS2_L;

		for(x=0;x<128;x++){
			//buf=pgm_read_byte(&img_dat[cnt]);
            buf = img_dat[cnt];
            
			if(x<64){
				GLCD_CS1_H;
			}else{
				GLCD_CS2_H;
			}

			GLCD_DATA(buf);

			if(x<64){
				GLCD_CS1_L;
			}else{
				GLCD_CS2_L;
			}
			cnt++;
		}
	}
}
#endif

/*
 * 
 */
int main(int argc, char** argv) {
    int         cnt = 0;
    int         bklt = 0;
    uint8_t     cmd;
    uint8_t     data;
    uint16_t   idx;
    EVENT_SWPDOWN = 0;
    
    InitApp();
//    output_high(PIN_LCD_BKLT);
//    disp_akizuki_sample();
    
    idx = 0;
    
    do {
        if(spi_data_is_in2() != 0){
            cmd = spi_read2();         // 引数あり　ではだめ
            switch (cmd){
            case CMD_IMAGEDATA:
                idx = 0;
                SpiTimer = 0;
                while (SpiTimer < 4){           // 2だと少し足りない
                    LcdBuf[idx++] = spi_read2();
                    if (idx == LCD_BUF_SIZE){
                        break;
                    }
                }
                break;
            case CMD_LCDDISPON:
                disp_lcd();
                GLCD_BKLT_ON;
                break;
            case CMD_LCDDISPOFF:
                GLCD_BKLT_OFF;
                break;
            case CMD_POWERDOWN:
                break;
            }
            //wait_ms(100);
        }
        
        if (EVENT_SWPDOWN){
            break;
        }
    } while (1);
    
program_end:
    output_low(PIN_PLOCK);
    while (1){
    }
    return (0);
}

void InitApp(){
    /* Initialize peripherals */
    setup_adc(ADC_OFF);         // ADC disabled
    setup_ccp1(CCP_OFF);        // CCP1 disabled
    setup_ccp2(CCP_OFF);        // CCP2 disabled
    setup_ccp3(CCP_OFF);        // CCP3 disabled
    
    setup_oscillator(OSC_8MHZ);
    
    output_high(PIN_PLOCK);
    port_b_pullups(0x10);     // B4=PIN_PDOWN
    output_float(PIN_PDOWN);

    // (1000us)/(4/8MHz)*250 = 8
    // -> 8*delay_cycle(250) = 1ms
    WaitMsCycle = 8;
    
    output_low(PIN_LCD_D0);
    output_low(PIN_LCD_D1);
    output_low(PIN_LCD_D2);
    output_low(PIN_LCD_D3);
    output_low(PIN_LCD_D4);
    output_low(PIN_LCD_D5);
    output_low(PIN_LCD_D6);
    output_low(PIN_LCD_D7);
    output_low(PIN_LCD_CS1);
    output_low(PIN_LCD_CS2);
    output_low(PIN_LCD_RESET);
    output_low(PIN_LCD_DI);
    output_low(PIN_LCD_RW);
    output_low(PIN_LCD_E);    
    GLCD_BKLT_OFF;
//    output_low(PIN_LCD_BKLT);
	glcd_init();		/* 液晶モジュールの初期化 */
    
    //setup_spi2(SPI_SLAVE | SPI_MODE_0);         // NG
    setup_spi2(SPI_SLAVE | SPI_MODE_1 | SPI_SS_DISABLED);   // OK
    
    // タイマーイベントハンドラが呼ばれる周期
    // Timer0 : (4/8MHz) * 1(prescaler) = 0.5us
    // 0.5us * 65536 = 32.7ms (TIMER0_INIT=0のとき)
    // 0.5us * (65536 - TIMER0_INIT) = 0.5us * 25536 = 12.7ms (TIMER0_INIT=40000のとき)
    // Timer0 : (4/8MHz) * 2(prescaler) = 1us
    // 1us * 65536 = 65.5ms (TIMER0_INIT=0のとき)
    setup_timer_0(T0_INTERNAL | T0_DIV_2);
    set_timer0(TIMER0_INIT);
    clear_interrupt(INT_TIMER0);
    enable_interrupts(INT_TIMER0);
    enable_interrupts(GLOBAL);
}

/*
	glcd_write()
	
	液晶モジュールにデータを送ります.
	予め送信先チップを選択しておく必要があります.
*/
void glcd_write(uint8_t cmd)
{
	GLCD_RW_L;
	GLCD_E_H;
	//PORT_LCD_DATA=cmd;
    output_bit(PIN_LCD_D0, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D1, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D2, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D3, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D4, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D5, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D6, (cmd & 0x01));
    cmd >>= 1;
    output_bit(PIN_LCD_D7, (cmd & 0x01));
	//_delay_us(6);
	GLCD_E_L;
	//_delay_us(2);
}

/*
	glcd_cls()
	
	画面を消去します.
	予め送信先チップを選択しておく必要があります.
*/
void glcd_fill(uint8_t patt)
{
	uint8_t x,y;

	for(y=0;y<8;y++){
		GLCD_SETPAGE(y);
		GLCD_SETADRS(0);
		for(x=0;x<64;x++){
			GLCD_DATA(patt);
		}
	}
}

/*
	glcd_init()
	
	液晶ディスプレイの初期化を行います.
	２個のチップを別々に初期化します.
*/
void glcd_init(void)
{
	GLCD_RST_H;			/* リセットを解除 */
	//_delay_ms(30);		/* 30ms(以上)ウェイト */
    wait_ms(30);

	GLCD_CS1_H;			/* 左半分担当チップ */
	GLCD_STRTLNE(0);		/* 表示開始位置のセット */
	glcd_fill(0xFF);		/* ピクセルテスト用に全部点灯*/
	GLCD_CS1_L;

	GLCD_CS2_H;			/* 右半分担当チップ */
	GLCD_STRTLNE(0);		/* 上と同じ */
	glcd_fill(0xFF);
	GLCD_CS2_L;


	GLCD_CS1_H;			/* 左半分担当チップ */
	GLCD_DISP_ON;			/* メモリ内容を表示する */
	GLCD_CS1_L;

	GLCD_CS2_H;			/* 右半分担当チップ */
	GLCD_DISP_ON;			/* 上と同じ */
	GLCD_CS2_L;
}

void disp_lcd(){
    
	uint8_t buf,x,y;
	uint16_t cnt=0;

	for(y=0; y<LCD_PAGES; y++){
		GLCD_CS1_H;
		GLCD_SETPAGE(y);
		GLCD_SETADRS(0);
		GLCD_CS1_L;

		GLCD_CS2_H;
		GLCD_SETPAGE(y);
		GLCD_SETADRS(0);
		GLCD_CS2_L;

		for(x=0; x<LCD_WIDTH; x++){
            //buf = LcdBuf[cnt];
            
			if(x<64){
				GLCD_CS1_H;
			}else{
				GLCD_CS2_H;
			}

			GLCD_DATA(LcdBuf[cnt]);

			if(x<64){
				GLCD_CS1_L;
			}else{
				GLCD_CS2_L;
			}
			cnt++;
		}
	}
}

#INT_TIMER0
void isr_timer0(){
    if (sw_pdown() == 0){
        EVENT_SWPDOWN = 1;
    }
    SpiTimer++;
}

void wait_ms(uint16_t ms){
    uint16_t    i;
    uint16_t    m;
    
    for (m=0; m<ms; m++){
        
        // 1ms
        for (i=0; i<WaitMsCycle; i++){
            delay_cycles(250);
        }
    }
}

#if 0
// LCD用出力ピンが出力として機能するかを確認する
void test_led(int no){
    output_low(PIN_LCD_D0);
    output_low(PIN_LCD_D1);
    output_low(PIN_LCD_D2);
    output_low(PIN_LCD_D3);
    output_low(PIN_LCD_D4);
    output_low(PIN_LCD_D5);
    output_low(PIN_LCD_D6);
    output_low(PIN_LCD_D7);
    output_low(PIN_LCD_CS1);
    output_low(PIN_LCD_CS2);
    output_low(PIN_LCD_RESET);
    output_low(PIN_LCD_DI);
    output_low(PIN_LCD_RW);
    output_low(PIN_LCD_E);
    
    if (no == 0) output_high(PIN_LCD_D0);
    if (no == 1) output_high(PIN_LCD_D1);
    if (no == 2) output_high(PIN_LCD_D2);
    if (no == 3) output_high(PIN_LCD_D3);
    if (no == 4) output_high(PIN_LCD_D4);
    if (no == 5) output_high(PIN_LCD_D5);
    if (no == 6) output_high(PIN_LCD_D6);
    if (no == 7) output_high(PIN_LCD_D7);
    if (no == 8) output_high(PIN_LCD_CS1);
    if (no == 9) output_high(PIN_LCD_CS2);
    if (no == 10) output_high(PIN_LCD_RESET);
    if (no == 11) output_high(PIN_LCD_DI);
    if (no == 12) output_high(PIN_LCD_RW);
    if (no == 13) output_high(PIN_LCD_E);
}
#endif

